@@ -51,31 +51,42 @@ def make_usage_message():
     return text
 
 
-def get_uploader_from_system(options):
-    """ Get the system value for the ‘uploader’ option. """
+def get_uploader_from_system(*, environ=None, debug=False):
+    """ Get the system value for the ‘uploader’ specification.
+
+        :param environ: Mapping of environment variables for this
+            process. (If ``None``, default to `os.environ`.)
+        :param debug: If true, enable debugging output.
+        :return: The uploader specification as a person specification
+            "Full Name <localpart@example.org>", if it can be
+            determined; otherwise ``None``.
+        """
     uploader = None
 
     # check environment for maintainer
-    if options['debug']:
+    if debug:
         sys.stdout.write(
                 "D: trying to get maintainer email from environment\n")
 
-    if 'DEBEMAIL' in os.environ:
+    if environ is None:
+        environ = os.environ
+
+    if 'DEBEMAIL' in environ:
         uploader = dputhelper.make_person_text_from_fields(
-                raw_text=os.environ['DEBEMAIL'],
-                full_name=os.environ.get('DEBFULLNAME', ""))
-        if options['debug']:
+                raw_text=environ['DEBEMAIL'],
+                full_name=environ.get('DEBFULLNAME', ""))
+        if debug:
             sys.stdout.write(
                     "D: Uploader from env: {}\n".format(uploader))
-    elif 'EMAIL' in os.environ:
+    elif 'EMAIL' in environ:
         uploader = dputhelper.make_person_text_from_fields(
-                raw_text=os.environ['EMAIL'],
-                full_name=os.environ.get('DEBFULLNAME', ""))
-        if options['debug']:
+                raw_text=environ['EMAIL'],
+                full_name=environ.get('DEBFULLNAME', ""))
+        if debug:
             sys.stdout.write(
                     "D: Uploader from env: {}\n".format(uploader))
     else:
-        if options['debug']:
+        if debug:
             sys.stdout.write("D: Guessing uploader\n")
         pwrec = pwd.getpwuid(os.getuid())
         username = pwrec[0]
@@ -85,7 +96,7 @@ def get_uploader_from_system(options):
         except IOError:
             hostname = ""
         if not hostname:
-            if options['debug']:
+            if debug:
                 sys.stdout.write(
                         "D: Guessing uploader: /etc/mailname was a failure\n")
             hostname_subprocess = subprocess.Popen(
@@ -97,11 +108,11 @@ def get_uploader_from_system(options):
         if hostname:
             uploader = (
                     "{fullname} <{username}@{hostname}>".format(**vars()))
-            if options['debug']:
+            if debug:
                 sys.stdout.write(
                         "D: Guessed uploader: {}\n".format(uploader))
         else:
-            if options['debug']:
+            if debug:
                 sys.stdout.write("D: Couldn't guess uploader\n")
 
     return uploader
@@ -111,7 +122,7 @@ def getoptions():
     # seed some defaults
     options = {
             'debug': 0, 'simulate': 0, 'config': None, 'host': None,
-            'uploader': None, 'keyid': None, 'passive': 0,
+            'uploader': None, 'keyid': None, 'commandline_passive': None,
             'filetocreate': None, 'filetoupload': None, 'changes': None}
     progname = dputhelper.get_progname(sys.argv)
     version = dputhelper.get_distribution_version()
@@ -153,7 +164,7 @@ def getoptions():
         elif option in ("-s", "--simulate"):
             options['simulate'] = 1
         elif option in ("-P", "--passive"):
-            options['passive'] = 1
+            options['commandline_passive'] = True
         elif option in ("-U", "--upload"):
             options['filetoupload'] = arg
         elif option in ("-O", "--output"):
@@ -178,7 +189,7 @@ def getoptions():
         del arguments[0]
 
     if not options['uploader']:
-        options['uploader'] = get_uploader_from_system(options)
+        options['uploader'] = get_uploader_from_system(debug=options['debug'])
 
     # we don't create command files without uploader
     if (
@@ -237,14 +248,13 @@ def parse_queuecommands(arguments, options, config):
     return commands
 
 
-def write_commands(commands, options, config, tempdir):
+def write_commands(commands, *, options, tempdir):
     """ Write a file of commands for the upload queue daemon.
 
         :param commands: Commands to write, as a sequence of text
             strings.
         :param options: Program configuration, as a mapping of options
             `{name: value}`.
-        :param config: `ConfigParser` instance for this application.
         :param tempdir: Filesystem path to directory for temporary files.
         :return: Filesystem path of file which was written.
 
@@ -272,12 +282,17 @@ def write_commands(commands, options, config, tempdir):
                 digits=string.digits))
         translationmap = str.maketrans(translationorig, translationdest)
         uploadpartforname = options['uploader'].translate(translationmap)
-        filename = (
-                "{progname}.{uploader_mapped}.{time:d}.{pid:d}.commands".format(
+        filename_stem = ".".join([
+                "{progname}",
+                "{uploader_mapped}",
+                "{time:d}",
+                "{pid:d}",
+                ]).format(
                     progname=progname,
                     uploader_mapped=uploadpartforname,
                     time=int(time.time()),
-                    pid=os.getpid()))
+                    pid=os.getpid())
+        filename = "{}.commands".format(filename_stem)
         if tempdir:
             filename = os.path.join(tempdir, filename)
     f = open(filename, 'w', encoding='UTF-8')
@@ -299,126 +314,6 @@ def write_commands(commands, options, config, tempdir):
     return filename
 
 
-def upload_stolen_from_dput_main(
-        host, upload_methods, config, debug, simulate,
-        files_to_upload, ftp_passive_mode):
-    """ Upload files to the host.
-
-        :param host: Configuration host name.
-        :param upload_methods: Mapping of {method_name: callable}.
-        :param config: `ConfigParser` instance for this application.
-        :param debug: If true, enable debugging output.
-        :param simulate: If true, simulate the upload only.
-        :param files_to_upload: Collection of file names to upload.
-        :param ftp_passive_mode: If true, enable FTP passive mode.
-        :return: ``None``.
-
-        Upload the specified files to the host, using the method and
-        credentials from the configuration for the host.
-        """
-    # Messy, yes. But it isn't referenced by the upload method anyway.
-    if config.get(host, 'method') == "local":
-        fqdn = "localhost"
-    else:
-        fqdn = config.get(host, 'fqdn')
-
-    # Check the upload methods that we have as default and per host
-    if debug:
-        sys.stdout.write(
-                "D: Default Method: {}\n".format(
-                    config.get('DEFAULT', 'method')))
-    if config.get('DEFAULT', 'method') not in upload_methods:
-        sys.stderr.write(
-                "Unknown upload method: {}\n".format(
-                    config.get('DEFAULT', 'method')))
-        sys.exit(1)
-    if debug:
-        sys.stdout.write("D: Host Method: {}\n".format(
-                config.get(host, 'method')))
-    if config.get(host, 'method') not in upload_methods:
-        sys.stderr.write(
-                "Unknown upload method: {}\n".format(
-                    config.get(host, 'method')))
-        sys.exit(1)
-
-    # Inspect the Config and set appropriate upload method
-    if not config.get(host, 'method'):
-        method = config.get('DEFAULT', 'method')
-    else:
-        method = config.get(host, 'method')
-
-    # Check now the login and redefine it if needed
-    if (
-            config.has_option(host, 'login')
-            and config.get(host, 'login') != "username"):
-        login = config.get(host, 'login')
-    elif (
-            config.has_option('DEFAULT', 'login')
-            and config.get('DEFAULT', 'login') != "username"):
-        login = config.get('DEFAULT', 'login')
-    else:
-        # Try to get the login from the enviroment
-        if 'USER' in os.environ:
-            login = os.environ['USER']
-        else:
-            sys.stdout.write("$USER not set, will use login information.\n")
-            # Else use the current username
-            login = pwd.getpwuid(os.getuid())[0]
-            if debug:
-                sys.stdout.write("D: User-ID: {}\n".format(os.getuid()))
-        if debug:
-            sys.stdout.write((
-                    "D: Neither host {host} nor default login used."
-                    " Using {login}\n").format(**vars()))
-    if debug:
-        sys.stdout.write("D: Login to use: {}\n".format(login))
-
-    incoming = config.get(host, 'incoming')
-    # Do the actual upload
-    if not simulate:
-        if debug:
-            sys.stdout.write("D: FQDN: {}\n".format(fqdn))
-            sys.stdout.write("D: Login: {}\n".format(login))
-            sys.stdout.write("D: Incoming: {}\n".format(incoming))
-        if method == 'ftp':
-            ftp_mode = config.getboolean(host, 'passive_ftp')
-            if ftp_passive_mode == 1:
-                ftp_mode = 1
-            if ftp_mode == 1:
-                if debug:
-                    if ftp_passive_mode == 1:
-                        sys.stdout.write("D: Using passive ftp\n")
-                    else:
-                        sys.stdout.write("D: Using active ftp\n")
-            upload_methods[method](
-                    fqdn, login, incoming,
-                    files_to_upload, debug, ftp_mode)
-        elif method == 'scp':
-            if debug and config.getboolean(host, 'scp_compress'):
-                sys.stdout.write("D: Setting compression for scp\n")
-            scp_compress = config.getboolean(host, 'scp_compress')
-            ssh_config_options = [
-                    y for y in (
-                        x.strip() for x in
-                        config.get(host, 'ssh_config_options').split("\n"))
-                    if y]
-            upload_methods[method](
-                    fqdn, login, incoming,
-                    files_to_upload, debug, scp_compress, ssh_config_options)
-        else:
-            upload_methods[method](
-                    fqdn, login, incoming,
-                    files_to_upload, debug, 0)
-    # Or just simulate it.
-    else:
-        for file_path in files_to_upload:
-            sys.stderr.write((
-                    "Uploading with {method}: {file_path}"
-                    " to {fqdn}:{incoming}\n"
-                    ).format(**vars()))
-            subprocess.call("cat {}".format(file_path), shell=True)
-
-
 def dcut():
     options, arguments = getoptions()
     if options['debug']:
@@ -483,34 +378,49 @@ def dcut():
             commands = None
             filename = options['filetoupload']
             if not filename.endswith(".commands"):
-                sys.stdout.write(
-                        "Error: I'm insisting on the .commands extension,"
-                        " which\n"
-                        "       \"{}\" doesnt seem to have.\n".format(filename))
+                sys.stdout.write(textwrap.dedent("""\
+                        Error: I'm insisting on the ‘.commands’ suffix, which
+                               ‘{}’ doesn't have.
+                        """).format(filename))
             # TV-TODO: check file to be readable?
         elif options['changes']:
             parse_changes = dput.parse_changes
-            removecommands = create_commands(options, config, parse_changes)
-            filename = write_commands(removecommands, options, config, tempdir)
+            commands = create_commands(options, parse_changes)
+            filename = write_commands(
+                    commands,
+                    options=options,
+                    tempdir=tempdir,
+                    )
         else:
             commands = parse_queuecommands(arguments, options, config)
-            filename = write_commands(commands, options, config, tempdir)
+            filename = write_commands(
+                    commands,
+                    options=options,
+                    tempdir=tempdir,
+                    )
         if not options['filetocreate']:
-            dput.import_upload_functions()
             upload_methods = dput.import_upload_functions()
-            upload_stolen_from_dput_main(
-                    options['host'], upload_methods, config,
-                    options['debug'], options['simulate'],
-                    [filename], options['passive'])
+            dput.upload_files(
+                    upload_methods, config, options['host'],
+                    [filename],
+                    simulate=options['simulate'],
+                    commandline_passive=options['commandline_passive'],
+                    debug=options['debug'])
     finally:
         # we use sys.exit, so we need to clean up here
         if tempdir:
             shutil.rmtree(tempdir)
 
 
-def create_commands(options, config, parse_changes):
+def create_commands(options, parse_changes):
     """ Get the removal commands from a package changes file.
 
+        :param options: The command-line options, as attributes in a namespace.
+        :param parse_changes: Callable object that accepts the package changes
+            file, and returns the mapping of fields.
+        :return: A sequence of `rm` commands for the files to remove on the
+            archive host.
+
         Parse the specified ‘foo.changes’ file and returns commands to
         remove files named in it.
         """
@@ -540,7 +450,7 @@ def create_commands(options, config, parse_changes):
     return removecommands
 
 
-# Copyright © 2015–2022 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2024 Ben Finney <bignose@debian.org>
 # Copyright © 2008–2013 Y Giridhar Appaji Nag <appaji@debian.org>
 # Copyright © 2004–2009 Thomas Viehmann <tv@beamnet.de>
 # Copyright © 2000–2004 Christian Kurz <shorty@debian.org>
