@@ -12,7 +12,7 @@ import locale
 import os
 import subprocess
 import sys
-import time
+import pwd
 
 import pkg_resources
 
@@ -25,6 +25,12 @@ class DputUploadFatalException(DputException):
     pass
 
 
+class UploadChangesInvalidVersionDputError(DputException):
+    """
+    Raised when an invalid ‘version’ field from upload changes control data.
+    """
+
+
 EXIT_STATUS_SUCCESS = 0
 EXIT_STATUS_FAILURE = 1
 EXIT_STATUS_COMMAND_NOT_FOUND = 127
@@ -257,8 +263,28 @@ def make_person_text_from_fields(*, raw_text, full_name=""):
         person_text = " ".join(fields)
     return person_text
 
+
+def get_username_from_system(debug=False):
+    """ Get the system username for the current process.
+
+        :param debug: If true, enable debugging output.
+        :return: The username determined from the current process.
+        """
+    login = None
+    if 'USER' in os.environ:
+        login = os.environ['USER']
+    else:
+        sys.stdout.write("$USER not set, will use login information.\n")
+        login = pwd.getpwuid(os.getuid())[0]
+        if debug:
+            sys.stderr.write("D: User-ID: {:d}\n".format(os.getuid()))
+    if debug:
+        sys.stderr.write("D: Login: {}\n".format(login))
+
+    return login
+
 
-# Copyright © 2015–2022 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2024 Ben Finney <bignose@debian.org>
 # Copyright © 2009–2010 Y Giridhar Appaji Nag <appaji@debian.org>
 # Copyright © 2007–2008 Thomas Viehmann <tv@beamnet.de>
 #
